isFuture property
bool
get
isFuture
Returns true if the current date is in the future.
Implementation
bool get isFuture => value.isAfter(DateTime.now());
Returns true if the current date is in the future.
bool get isFuture => value.isAfter(DateTime.now());