isPast property
bool
get
isPast
Returns true if the current date is in the past.
Implementation
bool get isPast => value.isBefore(DateTime.now());
Returns true if the current date is in the past.
bool get isPast => value.isBefore(DateTime.now());