forEach method
void
forEach(
- void action(
- T e
Applies action to each element of the current iterable.
Implementation
void forEach(void Function(T e) action) {
value.forEach(action);
}
Applies action to each element of the current iterable.
void forEach(void Function(T e) action) {
value.forEach(action);
}