lastOrNull property
T?
get
lastOrNull
Returns the last element, or null if the iterable is empty.
Implementation
T? get lastOrNull => value.lastOrNull;
Returns the last element, or null if the iterable is empty.
T? get lastOrNull => value.lastOrNull;