ReactiveList<T> extension

on

Methods

add(T item) → void

Available on Reactive<List<T>>, provided by the ReactiveList extension

Adds item to the end of the list.
addAll(Iterable<T> items) → void

Available on Reactive<List<T>>, provided by the ReactiveList extension

Adds all items from items to the end of the list.
addFirst(T item) → void

Available on Reactive<List<T>>, provided by the ReactiveList extension

Adds item to the end of the list.
addToSet(T item) → void

Available on Reactive<List<T>>, provided by the ReactiveList extension

Adds item to the list only if it does not already exist.
clear() → void

Available on Reactive<List<T>>, provided by the ReactiveList extension

Clears the list.
remove(T item) → void

Available on Reactive<List<T>>, provided by the ReactiveList extension

Removes item from the list.
removeAll(T item) → void

Available on Reactive<List<T>>, provided by the ReactiveList extension

Removes all occurrences of item.
removeWhere(bool test(T)) → void

Available on Reactive<List<T>>, provided by the ReactiveList extension

Removes all elements that match test.
sort([int compare(T a, T b)?]) → void

Available on Reactive<List<T>>, provided by the ReactiveList extension

Sort the list in place using the provided compare function.

Operators

operator [](int index) → T

Available on Reactive<List<T>>, provided by the ReactiveList extension

operator []=(int i, T v) → void

Available on Reactive<List<T>>, provided by the ReactiveList extension