operator []= method
Replaces the element at index i with v and notifies listeners.
Implementation
void operator []=(int i, T v) {
value[i] = v;
notify();
}
Replaces the element at index i with v and notifies listeners.
void operator []=(int i, T v) {
value[i] = v;
notify();
}