sort method
Sort the list in place using the provided compare function.
Implementation
void sort([int Function(T a, T b)? compare]) {
final list = value.toList();
list.sort(compare);
value = list;
}
Sort the list in place using the provided compare function.
void sort([int Function(T a, T b)? compare]) {
final list = value.toList();
list.sort(compare);
value = list;
}