sort method
Sort the list in place using the provided compare function.
Implementation
void sort([int Function(T a, T b)? compare]) {
value.sort(compare);
notify();
}
Sort the list in place using the provided compare function.
void sort([int Function(T a, T b)? compare]) {
value.sort(compare);
notify();
}