operator []= method
void
operator []=(
- K k,
- V v
Sets the value for key k to v and notifies listeners.
Implementation
void operator []=(K k, V v) {
value[k] = v;
notify();
}
Sets the value for key k to v and notifies listeners.
void operator []=(K k, V v) {
value[k] = v;
notify();
}