ReactiveString extension

Extension for Reactive<String> providing common string utilities.

on

Properties

isEmpty bool

Available on Reactive<String>, provided by the ReactiveString extension

Returns true if the string is empty after trimming whitespace.
no setter
isNotEmpty bool

Available on Reactive<String>, provided by the ReactiveString extension

Returns true if the string is not empty after trimming whitespace.
no setter
length int

Available on Reactive<String>, provided by the ReactiveString extension

Returns the length of the string.
no setter
lower String

Available on Reactive<String>, provided by the ReactiveString extension

no setter
trimmed String

Available on Reactive<String>, provided by the ReactiveString extension

Returns the trimmed value
no setter
upper String

Available on Reactive<String>, provided by the ReactiveString extension

no setter

Methods

append(String text) → void

Available on Reactive<String>, provided by the ReactiveString extension

Appends text to the current string.
clear() → void

Available on Reactive<String>, provided by the ReactiveString extension

Clears the string, setting it to an empty value.
contains(String other, {bool caseSensitive = true}) bool

Available on Reactive<String>, provided by the ReactiveString extension

Checks if the string contains other.
endsWith(Object other, {bool caseSensitive = true}) bool

Available on Reactive<String>, provided by the ReactiveString extension

Returns true if the string ends with other.
prepend(String text) → void

Available on Reactive<String>, provided by the ReactiveString extension

Prepends text to the current string.
startsWith(Object other, {bool caseSensitive = true}) bool

Available on Reactive<String>, provided by the ReactiveString extension

Returns true if the string starts with other.
toLower() → void

Available on Reactive<String>, provided by the ReactiveString extension

Converts the string to lowercase.
toUpper() → void

Available on Reactive<String>, provided by the ReactiveString extension

Converts the string to uppercase.
trim() → void

Available on Reactive<String>, provided by the ReactiveString extension

Trims whitespace from the start and end of the string.

Operators

operator +(Object other) String

Available on Reactive<String>, provided by the ReactiveString extension

Concatenates this value with other and returns a new String.
operator <(Object other) bool

Available on Reactive<String>, provided by the ReactiveString extension

Returns true if this value is less than other (lexicographic order).
operator <=(Object other) bool

Available on Reactive<String>, provided by the ReactiveString extension

Returns true if this value is less than or equal to other.
operator >(Object other) bool

Available on Reactive<String>, provided by the ReactiveString extension

Returns true if this value is greater than other.
operator >=(Object other) bool

Available on Reactive<String>, provided by the ReactiveString extension

Returns true if this value is greater than or equal to other.