unbind method
Unbinds a previously bound State.
The state will no longer rebuild when the value changes.
Implementation
void unbind(State state) => _boundStates.remove(state);
Unbinds a previously bound State.
The state will no longer rebuild when the value changes.
void unbind(State state) => _boundStates.remove(state);