ReactiveString extension
Extension for Reactive<String> providing common string utilities.
Properties
- isEmpty → bool
-
Available on Reactive<
Returns true if the string is empty after trimming whitespace.String> , provided by the ReactiveString extensionno setter - isNotEmpty → bool
-
Available on Reactive<
Returns true if the string is not empty after trimming whitespace.String> , provided by the ReactiveString extensionno setter - length → int
-
Available on Reactive<
Returns the length of the string.String> , provided by the ReactiveString extensionno setter - lower → String
-
Available on Reactive<
String> , provided by the ReactiveString extensionno setter - trimmed → String
-
Available on Reactive<
Returns the trimmed valueString> , provided by the ReactiveString extensionno setter - upper → String
-
Available on Reactive<
String> , provided by the ReactiveString extensionno setter
Methods
-
append(
String text) → void -
Available on Reactive<
AppendsString> , provided by the ReactiveString extensiontextto the current string. -
clear(
) → void -
Available on Reactive<
Clears the string, setting it to an empty value.String> , provided by the ReactiveString extension -
contains(
String other, {bool caseSensitive = true}) → bool -
Available on Reactive<
Checks if the string containsString> , provided by the ReactiveString extensionother. -
endsWith(
Object other, {bool caseSensitive = true}) → bool -
Available on Reactive<
Returns true if the string ends withString> , provided by the ReactiveString extensionother. -
prepend(
String text) → void -
Available on Reactive<
PrependsString> , provided by the ReactiveString extensiontextto the current string. -
startsWith(
Object other, {bool caseSensitive = true}) → bool -
Available on Reactive<
Returns true if the string starts withString> , provided by the ReactiveString extensionother. -
toLower(
) → void -
Available on Reactive<
Converts the string to lowercase.String> , provided by the ReactiveString extension -
toUpper(
) → void -
Available on Reactive<
Converts the string to uppercase.String> , provided by the ReactiveString extension -
trim(
) → void -
Available on Reactive<
Trims whitespace from the start and end of the string.String> , provided by the ReactiveString extension
Operators
-
operator +(
Object other) → String -
Available on Reactive<
Concatenates this value withString> , provided by the ReactiveString extensionotherand returns a new String. -
operator <(
Object other) → bool -
Available on Reactive<
Returns true if this value is less thanString> , provided by the ReactiveString extensionother(lexicographic order). -
operator <=(
Object other) → bool -
Available on Reactive<
Returns true if this value is less than or equal toString> , provided by the ReactiveString extensionother. -
operator >(
Object other) → bool -
Available on Reactive<
Returns true if this value is greater thanString> , provided by the ReactiveString extensionother. -
operator >=(
Object other) → bool -
Available on Reactive<
Returns true if this value is greater than or equal toString> , provided by the ReactiveString extensionother.