ReactiveBuilder class
A widget that rebuilds automatically from any reactive values read inside its builder.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ReactiveBuilder
Constructors
- ReactiveBuilder(Widget builder(), {Key? key})
-
const
Properties
- builder → Widget Function()
-
Builder function whose reactive reads are tracked automatically.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ReactiveBuilder> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
stream<
T> (Reactive< T> reactive, AsyncWidgetBuilder<T> builder, {Key? key, bool withInitial = true}) → Widget -
Builds a StreamBuilder wired to the
reactivestream. -
watch<
T> (Reactive< T> reactive, Widget builder(T value), {Key? key}) → Widget -
Build a widget from a specific
reactivevalue. -
watch2<
A, B> (Reactive< A> a, Reactive<B> b, Widget builder(A a, B b), {Key? key}) → Widget - Build a widget from two explicit reactive values.
-
watch3<
A, B, C> (Reactive< A> a, Reactive<B> b, Reactive<C> c, Widget builder(A a, B b, C c), {Key? key}) → Widget - Build a widget from three explicit reactive values.
-
watch4<
A, B, C, D> (Reactive< A> a, Reactive<B> b, Reactive<C> c, Reactive<D> d, Widget builder(A a, B b, C c, D d), {Key? key}) → Widget - Build a widget from four explicit reactive values.
-
watch5<
A, B, C, D, E> (Reactive< A> a, Reactive<B> b, Reactive<C> c, Reactive<D> d, Reactive<E> e, Widget builder(A a, B b, C c, D d, E e), {Key? key}) → Widget - Build a widget from five explicit reactive values.